==> haskell-hunit-1.6.2.0-190-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-JGxgr0O3qDr2sR1C0CRfuz
key:                  HUnit-1.6.2.0-JGxgr0O3qDr2sR1C0CRfuz
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  973028067dd6f659972897532928fec9
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.0.2/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hunit
hs-libraries:         HSHUnit-1.6.2.0-JGxgr0O3qDr2sR1C0CRfuz
depends:
    base-4.15.1.0 call-stack-0.4.0-AF4gWC5rZiPGBfZc4bnMry
    deepseq-1.4.5.0

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hunit-1.6.2.0-237-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HUnit
version:              1.6.2.0
visibility:           public
id:                   HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
key:                  HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
license:              BSD-3-Clause
maintainer:           Simon Hengel <sol@typeful.net>
author:               Dean Herington
stability:            stable
homepage:             https://github.com/hspec/HUnit#readme
synopsis:             A unit testing framework for Haskell
description:
    HUnit is a unit testing framework for Haskell, inspired by the
    JUnit tool for Java, see: <http://www.junit.org>.

category:             Testing
abi:                  1ebf31daff257f7d6deb9f297d19bdc0
exposed:              True
exposed-modules:
    Test.HUnit Test.HUnit.Base Test.HUnit.Lang Test.HUnit.Terminal
    Test.HUnit.Text

hidden-modules:       Paths_HUnit
import-dirs:          /usr/lib/ghc-9.2.8/site-local/HUnit-1.6.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HUnit-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hunit
hs-libraries:         HSHUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
depends:
    base-4.16.4.0 call-stack-0.4.0-7Kj6UtaYY94JDoMxAZHX8y
    deepseq-1.4.6.1

haddock-interfaces:   /usr/share/doc/haskell-hunit/html/HUnit.haddock
haddock-html:         /usr/share/doc/haskell-hunit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
